/* © 2024 Appstock */

/*   Copyright 2018-2021 Prebid.org, Inc.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/*
 CHANGE NOTICE: The file content was modified to rebrand the work, adapt the product for the new use case, and change the distribution license.
 The patch to the original code is available in the APS repository.
 All changes after applying the patch are made under the new license and copyrights mentioned at the beginning of this file.
*/

#import <UIKit/UIKit.h>
#import "STKConstants.h"
#import "STKVoidBlock.h"

@class STKModalState;
@class STKAdConfiguration;
@class STKInterstitialDisplayProperties;

typedef void (^STKModalStatePopHandler)(STKModalState * _Nullable poppedState);
typedef void (^STKModalStateAppLeavingHandler)(STKModalState * _Nullable leavingState);

@interface STKModalState: NSObject

@property (nonatomic, strong, nullable, readonly) STKAdConfiguration *adConfiguration;
@property (nonatomic, strong, nullable, readonly) STKInterstitialDisplayProperties *displayProperties;
@property (nonatomic, strong, nullable, readonly) UIView *view;

@property (nonatomic, copy, nonnull) STKMRAIDState mraidState;

@property (nonatomic, copy, nullable, readonly) STKModalStatePopHandler onStatePopFinished;
@property (nonatomic, copy, nullable, readonly) STKModalStateAppLeavingHandler onStateHasLeftApp;

// Used to transfer delegate function to another object, rather then current delegate for next states pushed on top
// ref: MOBILE-5849
@property (nonatomic, copy, nullable, readonly) STKModalStatePopHandler nextOnStatePopFinished;
@property (nonatomic, copy, nullable, readonly) STKModalStateAppLeavingHandler nextOnStateHasLeftApp;

@property (nonatomic, strong, nullable) STKVoidBlock onModalPushedBlock;

@property (nonatomic, assign, readonly, getter=isRotationEnabled) BOOL rotationEnabled;

- (nonnull instancetype)init NS_UNAVAILABLE;

+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable STKAdConfiguration *)adConfiguration
                         displayProperties:(nullable STKInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable STKModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable STKModalStateAppLeavingHandler)onStateHasLeftApp;


+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable STKAdConfiguration *)adConfiguration
                         displayProperties:(nullable STKInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable STKModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable STKModalStateAppLeavingHandler)onStateHasLeftApp
                    nextOnStatePopFinished:(nullable STKModalStatePopHandler)nextOnStatePopFinished
                     nextOnStateHasLeftApp:(nullable STKModalStateAppLeavingHandler)nextOnStateHasLeftApp;


+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable STKAdConfiguration *)adConfiguration
                         displayProperties:(nullable STKInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable STKModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable STKModalStateAppLeavingHandler)onStateHasLeftApp
                        onModalPushedBlock:(nullable STKVoidBlock)onModalPushedBlock;

+ (nonnull instancetype)modalStateWithView:(nonnull UIView *)view
                           adConfiguration:(nullable STKAdConfiguration *)adConfiguration
                         displayProperties:(nullable STKInterstitialDisplayProperties *)displayProperties
                        onStatePopFinished:(nullable STKModalStatePopHandler)onStatePopFinished
                         onStateHasLeftApp:(nullable STKModalStateAppLeavingHandler)onStateHasLeftApp
                    nextOnStatePopFinished:(nullable STKModalStatePopHandler)nextOnStatePopFinished
                     nextOnStateHasLeftApp:(nullable STKModalStateAppLeavingHandler)nextOnStateHasLeftApp
                        onModalPushedBlock:(nullable STKVoidBlock)onModalPushedBlock;

@end
