/* © 2024 Appstock */

/*   Copyright 2018-2021 Prebid.org, Inc.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 */

/*
 CHANGE NOTICE: The file content was modified to rebrand the work, adapt the product for the new use case, and change the distribution license.
 The patch to the original code is available in the APS repository.
 All changes after applying the patch are made under the new license and copyrights mentioned at the beginning of this file.
*/

#import <Foundation/Foundation.h>
#import "STKORTBBidExtSkadn.h"

@protocol STKTransactionDelegate;

@class WKWebView;
@class UIView;
@class STKModalManager;
@class STKAdConfiguration;
@class STKCreativeModel;
@class STKAbstractCreative;
@class STKAdDetails;
@class STKOpenMeasurementSession;
@class STKOpenMeasurementWrapper;
@class STKORTBBidExtSkadn;

@protocol APSServerConnectionProtocol;

NS_ASSUME_NONNULL_BEGIN
@interface STKTransaction: NSObject

@property (nonatomic, readonly, nonnull) STKAdConfiguration *adConfiguration; // If need to change use resetAdConfiguration
@property (nonatomic, strong) NSMutableArray<STKAbstractCreative *> *creatives;
@property (nonatomic, strong) NSArray<STKCreativeModel *> *creativeModels;
@property (nonatomic, strong, nullable) STKOpenMeasurementSession *measurementSession;
@property (nonatomic, strong) STKOpenMeasurementWrapper *measurementWrapper;

@property (nonatomic, strong, nullable) STKORTBBidExtSkadn *skadnInfo;
@property (nonatomic, strong, nullable) NSString *impURL; // bidResponse.ext.mobilesdk.events.imp
@property (nonatomic, strong, nullable) NSString *winURL; // bidResponse.ext.mobilesdk.events.win

@property (atomic, weak, nullable) id<STKTransactionDelegate> delegate;

- (instancetype)init NS_UNAVAILABLE;
- (instancetype)initWithServerConnection:(id<APSServerConnectionProtocol>)connection
                         adConfiguration:(STKAdConfiguration *)adConfiguration
                                  models:(NSArray<STKCreativeModel *> *)creativeModels NS_DESIGNATED_INITIALIZER;

- (void)startCreativeFactory;
- (nullable STKAdDetails *)getAdDetails;
- (nullable STKAbstractCreative *)getFirstCreative;
- (nullable STKAbstractCreative *)getCreativeAfter:(STKAbstractCreative *)creative;
- (nullable NSString*)revenueForCreativeAfter:(STKAbstractCreative *)creative;
- (void)resetAdConfiguration:(STKAdConfiguration *)adConfiguration;

@end
NS_ASSUME_NONNULL_END
